@@ -6,7 +6,7 @@ from datetime import timedelta
 __author__      = 'Luca Baronti'
 __maintainer__  = 'Luca Baronti'
 __license__     = 'MIT'
-__version__     = '1.0.2'
+__version__     = '1.0.3'
 
 class Stopwatch(object):
   def __init__(self, task_name='', verbosity=2, streams=[sys.stdout]):
@@ -16,6 +16,9 @@ class Stopwatch(object):
     self.verbosity = verbosity
     self.__enter__()
 
+  def __str__(self):
+    return str(Stopwatch.time_from_seconds(self.get_elapsed_time()))
+
   def _print_on_streams(self, message):
     for strm in self.streams:
       strm.write(message)
